@@ -38,6 +38,8 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/lib ; ln -sf libkickermain.so.1.0.0 libkickermain.so )
 ( cd opt/kde/lib ; rm -rf libtaskmanager.so )
 ( cd opt/kde/lib ; ln -sf libtaskmanager.so.1.0.0 libtaskmanager.so )
+( cd opt/kde/lib ; rm -rf libkasbar.so )
+( cd opt/kde/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so )
 ( cd opt/kde/lib ; rm -rf libkfontinst.so )
 ( cd opt/kde/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so )
 ( cd opt/kde/lib ; rm -rf libksgrd.so.1 )
@@ -48,6 +50,8 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so.0 )
 ( cd opt/kde/lib ; rm -rf libtaskmanager.so.1 )
 ( cd opt/kde/lib ; ln -sf libtaskmanager.so.1.0.0 libtaskmanager.so.1 )
+( cd opt/kde/lib ; rm -rf libkasbar.so.1 )
+( cd opt/kde/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so.1 )
 ( cd opt/kde/lib ; rm -rf libtaskbar.so )
 ( cd opt/kde/lib ; ln -sf libtaskbar.so.1.2.0 libtaskbar.so )
 ( cd opt/kde/lib ; rm -rf libkateinterfaces.so )
@@ -66,6 +70,8 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kxkb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdcop ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdesu ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kfind ; rm -rf common )
@@ -90,6 +96,8 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kioslave ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/knetattach ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/smb ; rm -rf common )
@@ -222,6 +230,8 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/ioports ; rm -rf common )
